# Changelog

## [integrations/azure_ai_search-v2.3.3] - 2025-12-10

### 🚀 Features

- Adding `update_by_filter()` and `delete_by_filter()` to `AzureAISearchDocument Store` (#2586)


### 🧪 Testing

- Fix the failing test for Azure AI (#2579)

### 🧹 Chores

- Remove Readme API CI workflow and configs (#2573)

### 🌀 Miscellaneous

- Adopt PEP 585 type hinting (part 1) (#2509)

## [integrations/azure_ai_search-v2.3.2] - 2025-11-11

### 🚀 Features

- Delete all documents for AzureAISearch DocumentStore (#2404)

### 📚 Documentation

- Add pydoc configurations for Docusaurus (#2411)
- Fix docstrings to avoid errors in API reference generation (#2423)

### ⚙️ CI

- Change pytest command (#2475)


## [integrations/azure_ai_search-v2.3.1] - 2025-10-10

### 🐛 Bug Fixes

- Azure AI Search - do not use Azure private types and simplify deserialization (#2372)


### 🧹 Chores

- Standardize readmes - part 1 (#2202)

## [integrations/azure_ai_search-v2.3.0] - 2025-06-27

### 🚀 Features

- Allow the scores returned by AI Search to be populated in the Document.meta (#1907)


## [integrations/azure_ai_search-v2.2.0] - 2025-06-27

### 🐛 Bug Fixes

- Fix Azure AI types + add py.typed (#2003)


### 🧹 Chores

- Align core-integrations Hatch scripts (#1898)
- Remove black (#1985)

## [integrations/azure_ai_search-v2.1.1] - 2025-06-04

### 🐛 Bug Fixes

- Correct Azure AI search _in delimiter (#1729)


## [integrations/azure_ai_search-v2.1.0] - 2025-06-04

### 🚀 Features

- Allow full metadata field customization (#1893)


## [integrations/azure_ai_search-v2.0.2] - 2025-05-14


### 🌀 Miscellaneous

- Feat: Add user-agent to `AzureAISearchDocumentStore` (#1743)

## [integrations/azure_ai_search-v2.0.1] - 2025-04-16

### 🚀 Features

- Fix serialization errors in `AzureAIDocumentStore` (#1647)


## [integrations/azure_ai_search-v2.0.0] - 2025-04-03

### 🐛 Bug Fixes

- [**breaking**] Rename env variables for Azure AI (#1597)


### ⚙️ CI

- Review testing workflows (#1541)

## [integrations/azure_ai_search-v1.0.0] - 2025-03-11


### 🧪 Testing

- Azure AI Search - improvements to the test suite (#1425)
- Skip tests that require credentials on PRs from forks for some integrations (#1485)

### 🧹 Chores

- Remove Python 3.8 support (#1421)
- Use Haystack logging across integrations (#1484)
- Azure AI - pin haystack and remove dataframe checks (#1500)

## [integrations/azure_ai_search-v0.1.3] - 2025-02-17


### 🧹 Chores

- Azure AI search - clarify that dataframe is not supported (#1407)

## [integrations/azure_ai_search-v0.1.2] - 2025-02-03

### 🐛 Bug Fixes

- Logger for index deletion failures in Azure AI (#1240)

### ⚙️ CI

- Delete all azure_ai_search indexes (#1247)

### 🧹 Chores

- Fix linting/isort (#1215)
- Inherit from `FilterDocumentsTestWithDataframe` in Document Stores (#1290)

### 🌀 Miscellaneous

- Fix: remove setting `query_type="simple"` in retrieval request (#1346)

## [integrations/azure_ai_search-v0.1.1] - 2024-11-22

### 🐛 Bug Fixes

- Fix error in README file (#1207)


## [integrations/azure_ai_search-v0.1.0] - 2024-11-21

### 🚀 Features

- Add Azure AI Search integration (#1122)
- Add BM25 and Hybrid Search Retrievers to Azure AI Search Integration (#1175)

### 🌀 Miscellaneous

- Enable kwargs in SearchIndex and Embedding Retriever (#1185)
- Fix: Fix tag name for version release (#1206)

<!-- generated by git-cliff -->
